Enum forkjoin::ReduceStyle
[−]
[src]
pub enum ReduceStyle<Ret> {
NoArg(TaskJoin<Ret>),
Arg(TaskJoinArg<Ret>),
}Enum indicating what type of join function an Algorithm will use.
Variants
NoArg | No extra argument is passed to the join function, only the resulting values of all subtasks |
Arg | Together with the result values of the subtasks, the join function will also
be passed an argument sent directly from the |